from enum import Enum


[
  "Amazon Elastic Container Registry Public",
  "Amazon Elastic Container Service",
  "Amazon Elastic Container Service for Kubernetes",
  "EC2 - Other",
  "Amazon Elastic File System",
  "Amazon Elastic Load Balancing",
  "Amazon Elastic MapReduce",
  "Amazon ElastiCache",
  "AWS Elemental MediaStore",
  "AWS End User Messaging",
  "AWS Fault Injection Simulator",
  "FinOps Practice Management",
  "AWS Firewall Manager",
  "Amazon FSx",
  "Amazon Glacier",
  "AWS Glue",
  "Amazon GuardDuty",
  "AWS HealthImaging",
  "AWS Identity and Access Management Access Analyzer",
  "AWS IoT",
  "AWS IoT Device Management",
  "Amazon Kendra",
  "Amazon Kinesis",
  "Amazon Kinesis Analytics",
  "Amazon Kinesis Firehose",
  "Amazon Kinesis Video Streams",
  "AWS Lake Formation",
  "AWS Lambda",
  "Amazon Lex",
  "Amazon Lightsail",
  "Amazon Location Service",
  "Amazon Lookout for Metrics",
  "Amazon Macie",
  "Amazon Managed Blockchain",
  "Amazon Managed Grafana",
  "Amazon Managed Streaming for Apache Kafka",
  "Amazon Managed Workflows for Apache Airflow",
  "Amazon MemoryDB",
  "AWS Migration Hub Refactor Spaces",
  "Amazon MQ",
  "Amazon Neptune",
  "Amazon OpenSearch Serverless",
  "Amazon OpenSearch Service",
  "Amazon Personalize",
  "Amazon Pinpoint",
  "Amazon Polly",
  "Amazon Q",
  "Amazon Quantum Ledger Database",
  "Amazon QuickSight",
  "Red Hat OpenShift Service on AWS",
  "Amazon Redshift",
  "Refund",
  "Amazon Registrar",
  "Amazon Rekognition",
  "Amazon Relational Database Service",
  "AWS Resilience Hub",
  "Amazon Route 53",
  "AWS Route 53 Application Recovery Controller",
  "Amazon Simple Storage Service",
  "Amazon SageMaker",
  "AWS Secrets Manager",
  "AWS Security Hub",
  "Amazon Security Lake",
  "AWS Service Catalog",
  "Amazon Simple Email Service",
  "Amazon Simple Workflow Service",
  "Amazon SimpleDB",
  "Amazon Simple Notification Service",
  "SPP Credit Custom Skin",
  "Amazon Simple Queue Service",
  "AWS Step Functions",
  "AWS Storage Gateway",
  "Amazon Sumerian",
  "AWS Support (Enterprise)",
  "AWS Systems Manager",
  "Tax",
  "Amazon Textract",
  "Amazon Timestream",
  "Amazon Transcribe",
  "AWS Transfer Family",
  "Amazon Translate",
  "Training Certification Voucher - Associate",
  "Amazon Verified Permissions",
  "Amazon Virtual Private Cloud",
  "AWS WAF",
  "Workforce Identity Solutions",
  "Amazon WorkSpaces",
  "Amazon WorkSpaces Thin Client",
  "AWS X-Ray"
]

class AWSServices(Enum):
    AMPLIFY='AWS Amplify'
    API_GATEWAY="Amazon API Gateway"
    APP_STREAM="Amazon AppStream"
    ATHENA="Amazon Athena"
    APP_SYNC="AWS AppSync"
    APP_FLOW="Amazon AppFlow"
    APP_STUDIO="AWS App Studio"
    APP_RUNNER="AWS App Runner"
    AUDIT_MANAGER="AWS Audit Manager"
    BACKUP="AWS Backup"
    BEDROCK="Amazon Bedrock"
    CERTIFICATE_MANAGER="AWS Certificate Manager"
    CODEARTIFACT="AWS CodeArtifact"
    CLOUD_TRAIL="AWS CloudTrail"
    CLOUD_WAN="AWS Cloud WAN"
    CLOUD_FORMATION="AWS CloudFormation"
    CLOUDFRONT="Amazon CloudFront"
    CLOUDHSM="AWS CloudHSM"
    CLOUDSEARCH="Amazon CloudSearch"
    CLOUDTRAIL="AWS CloudTrail"
    CLOUDWATCH="AmazonCloudWatch"
    CLOUDWATCH_EVENTS="CloudWatch Events"
    CODEBUILD="CodeBuild"
    CODECATALYST="CodeCatalyst"
    CODECOMMIT="AWS CodeCommit"
    CODEGURU="CodeGuru"
    CODEPIPELINE="AWS CodePipeline"
    CODEWHISPERER="Amazon CodeWhisperer"
    COGNITO="Amazon Cognito"
    COGNITO_SYNC="Amazon Cognito Sync"
    COMPREHEND="Amazon Comprehend"
    COMPUTE_OPTIMIZER="AWS Compute Optimizer"
    CONFIG="AWS Config"
    CONNECT="Amazon Connect"
    COST_EXPLORER="AWS Cost Explorer"
    DATA_PIPELINE="AWS Data Pipeline"
    DATA_TRANSFER="AWS Data Transfer"
    DATASYNC="AWS DataSync"
    DATAZONE="Amazon DataZone"
    DEEPRACER="AWS DeepRacer"
    DETECTIVE="Amazon Detective"
    DEVICE_FARM="AWS Device Farm"
    DEVOPS_GURU="Amazon DevOps Guru"
    DIRECT_CONNECT="AWS Direct Connect"
    DIRECTORY_SERVICE="AWS Directory Service"
    DATABASE_MIGRATION_SERVICE="AWS Database Migration Service"
    DOCUMENTDB="Amazon DocumentDB (with MongoDB compatibility)"
    DYNAMODB="Amazon DynamoDB"
    EC2='Amazon Elastic Compute Cloud - Compute'
    ECR='Amazon EC2 Container Registry (ECR)'
    ELASTICACHE='Amazon ElastiCache'
    RDS='Amazon Relational Database Service'